#!/usr/bin/env python3

from gi.repository import Gtk, GLib, GdkPixbuf

class ComipoliThumbnail(Gtk.Dialog):
    def __init__(self, owner):
        Gtk.Dialog.__init__(self, modal=True, transient_for=owner, title='Comipoli Thumbnail')
        self.owner = owner
        self.psize = owner.props.application.thumbnail_height
        self.fbox = Gtk.FlowBox(
            valign=Gtk.Align.START,
            max_children_per_line=10,
            homogeneous=True,
            selection_mode=Gtk.SelectionMode.BROWSE)
        self.fbox.connect('child-activated', self.on_flowbox_child_activated)
        #self.fbox.set_activate_on_single_click(False)
        scroll = Gtk.ScrolledWindow()
        scroll.set_child(self.fbox)
        vbox = self.get_content_area()
        vbox.append(scroll)
        # size
        x, y = self.owner.get_default_size()
        self.set_default_size(x, y)
        # idle
        self.generator = self.add_thumbnail()
        GLib.idle_add(self.idle_function)

    def idle_function(self):
        try:
            next(self.generator)
            return True
        except StopIteration:
            return False

    def add_thumbnail(self):
        for num, buf in enumerate(self.owner.thumbnail_array):
            image = Gtk.Image.new_from_pixbuf(pixbuf=buf)
            image.set_pixel_size(self.psize)
            label = Gtk.Label(
                label=f'<span color="#ff0000" background="#66ffff" background_alpha="50%">{num+1}</span>',
                use_markup=True,
                halign=Gtk.Align.CENTER,
                valign=Gtk.Align.END)
            overlay = Gtk.Overlay(vexpand=True, hexpand=True)
            overlay.set_child(image)
            overlay.add_overlay(label)
            self.fbox.insert(overlay, num)
            # Focus
            if num == self.owner.num:
                child = self.fbox.get_child_at_index(num)
                self.fbox.select_child(child)
                #self.set_focus(child)
                child.grab_focus()
            yield 1

    def on_flowbox_child_activated(self, fbox, child):
        num = child.get_index()
        self.owner.num = num - 1
        self.owner.change_pixbuf(1)
        self.hide()

